@@ -1,6 +1,6 @@
 package File::RsyBak;
 BEGIN {
-  $File::RsyBak::VERSION = '0.11';
+  $File::RsyBak::VERSION = '0.12';
 }
 # ABSTRACT: Backup files/directories with histories, using rsync
 
@@ -349,7 +349,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -421,7 +421,7 @@ interfering:
 
 Then we copy source to temporary directory:
 
- rsync .. SRC            TARGET/.tmp
+ rsync    SRC            TARGET/.tmp
 
 If copy finishes successfully, we rename temporary directory to final directory
 'current':
@@ -432,7 +432,7 @@ If copy finishes successfully, we rename temporary directory to final directory
 If copy fails in the middle, TARGET/.tmp will still be lying around and the next
 backup run will just continue the rsync process:
 
- rsync .. SRC            TARGET/.tmp
+ rsync    SRC            TARGET/.tmp
 
 Finally, we remove lock:
 
@@ -446,7 +446,7 @@ First, we lock target directory to prevent other backup process to interfere:
 
 Then we rsync source to target directory (using --link-dest=TARGET/current):
 
- rsync .. SRC            TARGET/.tmp
+ rsync    SRC            TARGET/.tmp
 
 If rsync finishes successfully, we rename target directories:
 
